| calc_seawater_correction | R Documentation |
Kgen seawater composition correction function
calc_seawater_correction(
k,
sal,
temp_c,
magnesium = 0.0528171,
calcium = 0.0102821,
method = "r_polynomial"
)
k |
K to be calculated |
sal |
Salinity |
temp_c |
Temperature (Celcius) |
magnesium |
Magnesium concentration in mol/kgsw. Default is modern seawater (0.0528171). Should be the average magnesium concentration in seawater - a salinity correction is then applied to calculate the magnesium concentration in the sample. |
calcium |
Calcium concentration in mol/kgsw. Default is modern seawater (0.0102821). Should be the average calcium concentration in seawater - a salinity correction is then applied to calculate the calcium concentration in the sample. |
method |
string describing method which should be either 'myami', 'myami_polynomial', or 'r_polynomial' (Default: 'r_polynomial'). |
list of seawater correction factors
Dennis Mayk
calc_seawater_correction("K1", sal = 35, temp_c = 25)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.