| kgen_poly | R Documentation |
Kgen R polynomial function
kgen_poly(sal, temp_c, magnesium = 0.0528171, calcium = 0.0102821)
sal |
Salinity |
temp_c |
Temperature (Celcius) |
magnesium |
Magnesium concentration in mol/kgsw. Default is modern seawater (0.0528171). Should be the average magnesium concentration in seawater - a salinity correction is then applied to calculate the magnesium concentration in the sample. |
calcium |
Calcium concentration in mol/kgsw. Default is modern seawater (0.0102821). Should be the average calcium concentration in seawater - a salinity correction is then applied to calculate the calcium concentration in the sample. |
Dennis Mayk
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.